@@ -38,7 +38,7 @@ using namespace Konsole;
 
 K_PLUGIN_FACTORY_WITH_JSON(KonsolePartFactory, "konsolepart.json", registerPlugin<Konsole::Part>();)
 
-Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
+Part::Part(QObject *parent, const QVariantList &)
     : KParts::ReadOnlyPart(parent)
     , _viewManager(nullptr)
     , _pluggedController(nullptr)
@@ -51,7 +51,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     connect(_viewManager, &Konsole::ViewManager::empty, this, &Konsole::Part::terminalExited);
     connect(_viewManager, &Konsole::ViewManager::newViewRequest, this, &Konsole::Part::newTab);
 
-    _viewManager->widget()->setParent(parentWidget);
+    _viewManager->widget()->setParent(widget());
 
     setWidget(_viewManager->widget());
     actionCollection()->addAssociatedWidget(_viewManager->widget());
@@ -177,7 +177,6 @@ QString Part::currentWorkingDirectory() const
     return activeSession()->currentWorkingDirectory();
 }
 
-#if USE_TERMINALINTERFACEV2
 QVariant Part::profileProperty(const QString &profileProperty) const
 {
     const auto metaEnum = QMetaEnum::fromType<Profile::Property>();
@@ -218,7 +217,6 @@ bool Part::setCurrentProfile(const QString &profileName)
     SessionManager::instance()->setSessionProfile(activeSession(), profile);
     return currentProfileName() == profileName;
 }
-#endif
 
 void Part::createSession(const QString &profileName, const QString &directory)
 {
@@ -394,3 +392,4 @@ void Part::notificationChanged(Session::Notification notification, bool enabled)
 }
 
 #include "Part.moc"
+#include "moc_Part.cpp"
