@@ -31,13 +31,14 @@ public:
     void getCells(const int lineno, const int colno, const int count, Character res[]) const override;
     bool isWrappedLine(const int lineno) const override;
     LineProperty getLineProperty(const int lineno) const override;
+    void setLineProperty(const int lineno, LineProperty prop) override;
 
     void addCells(const Character text[], const int count) override;
     void addCellsMove(Character text[], const int count) override
     {
         addCells(text, count);
     } // TODO: optimize, if there's any point
-    void addLine(LineProperty lineProperty = 0) override;
+    void addLine(LineProperty lineProperty = LineProperty()) override;
 
     // Modify history
     void removeCells() override;
