@@ -236,32 +236,19 @@ bool Session::hasFocus() const
     });
 }
 
-void Session::setCodec(QTextCodec *codec)
-{
-    if (isReadOnly()) {
-        return;
-    }
-
-    emulation()->setCodec(codec);
-
-    Q_EMIT sessionCodecChanged(codec);
-}
-
 bool Session::setCodec(const QByteArray &name)
 {
-    QTextCodec *codec = QTextCodec::codecForName(name);
-
-    if (codec != nullptr) {
-        setCodec(codec);
-        return true;
-    } else {
+    if (isReadOnly() || !emulation()->setCodec(name)) {
         return false;
     }
+
+    Q_EMIT sessionCodecChanged(codec());
+    return true;
 }
 
 QByteArray Session::codec()
 {
-    return _emulation->codec()->name();
+    return _emulation->encoder().name();
 }
 
 void Session::setProgram(const QString &program)
@@ -281,7 +268,7 @@ void Session::setInitialWorkingDirectory(const QString &dir)
 
 QString Session::currentWorkingDirectory()
 {
-    if (_reportedWorkingUrl.isValid() && _reportedWorkingUrl.isLocalFile()) {
+    if (_reportedWorkingUrl.isValid() && _reportedWorkingUrl.isLocalFile() && (_reportedWorkingUrl.host().length() == 0 || _reportedWorkingUrl.host().compare(QSysInfo::machineHostName(), Qt::CaseInsensitive) == 0)) {
         return _reportedWorkingUrl.path();
     }
 
@@ -445,15 +432,15 @@ QString Session::shellSessionId() const
     return friendlyUuid;
 }
 
-static QStringList postProcessArgs(const QStringList &args)
+static QStringList postProcessArgs(const QStringList &contextArgs, const QStringList &args)
 {
 #ifndef Q_OS_WIN
     if (!KSandbox::isFlatpak()) {
-        return args;
+        return contextArgs + args;
     }
     QStringList arguments;
     // last arg is the program
-    arguments = args;
+    arguments = contextArgs;
     QString program = arguments.back();
     arguments.pop_back();
     // Needs to be explicitly specified, KSandbox::makeHostContext
@@ -461,6 +448,7 @@ static QStringList postProcessArgs(const QStringList &args)
     // never gets set.
     arguments.push_back(QStringLiteral("--env=TERM=xterm-256color"));
     arguments.push_back(program);
+    arguments << args;
     return arguments;
 #else
     qCritical() << "Should never get called on windows";
@@ -576,10 +564,9 @@ void Session::run()
 #ifndef Q_OS_WIN
     const auto originalEnvironment = _shellProcess->environment();
     _shellProcess->setProgram(exec);
-    _shellProcess->setArguments(arguments);
     _shellProcess->setEnvironment(originalEnvironment + _environment);
     const auto context = KSandbox::makeHostContext(*_shellProcess);
-    arguments = postProcessArgs(context.arguments);
+    arguments = postProcessArgs(context.arguments, arguments);
     _shellProcess->setEnvironment(originalEnvironment);
     const auto result = _shellProcess->start(context.program, arguments, _environment);
 #else // Q_OS_WIN
