@@ -96,17 +96,6 @@ public:
 
     void applyProfile(const QExplicitlySharedDataPointer<Profile> &profile);
 
-    /**
-     * Sets the seed used to generate random colors for the display
-     * (in color schemes that support them).
-     */
-    void setRandomSeed(uint randomSeed);
-    /**
-     * Returns the seed used to generate random colors for the display
-     * (in color schemes that support them).
-     */
-    uint randomSeed() const;
-
     /** Sets the opacity of the terminal display. */
     void setOpacity(qreal opacity);
 
@@ -716,8 +705,6 @@ private:
 
     QColor _colorTable[TABLE_COLORS];
 
-    uint _randomSeed = 0;
-
     bool _resizing = false;
     bool _showTerminalSizeHint = true;
     bool _bidiEnabled = false;
